@@ -2,11 +2,12 @@
 #define HALKEYBOARDS_H
 
 #include <QMap>
+#include <QWidget>
 
 class HalKeyboards:public QMap< QString,QString >
 {
 public:
-    HalKeyboards();
+    HalKeyboards(QWidget * parent);
 };
 
 #endif // HALKEYBOARDS_H
